.. perfwhiz documentation master file, created by
   sphinx-quickstart on Mon Nov 23 16:43:59 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the perfwhiz documentation!
======================================

Contents:

.. toctree::
   :maxdepth: 2

   overview 
   installation
   usage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

